# Linguistic System and Sociolinguistic Environment

Kaius Sinnemäki & Noora Ahola, University of Helsinki

***

This repository contains the supplementary data for the following article; please cite it when using the data:

Sinnemäki, Kaius 2020. Linguistic system and sociolinguistic environment as competing factors in linguistic variation: A typological approach. *Journal of Historical Sociolinguistics* 6(2): 20190101. https://doi.org/10.1515/jhsl-2019-1010


The supplement is available also at the journal's website, but only as a zipped file. Here we provide the data and metadata in a computer-readable form, roughly following the practices of the [AUTOTYP](https://github.com/autotyp/autotyp-data) database. This repository has been created by Kaius Sinnemäki with the assistance of Noora Ahola.


`DOI badge and link here`


***

## Contents

### [Bibliography](https://version.helsinki.fi/gramadapt/linguistic-system-and-sociolinguistic-environment/-/tree/master/bibliography)

The sources for all entries are listed in the file references.bib.


### [Data](https://version.helsinki.fi/gramadapt/linguistic-system-and-sociolinguistic-environment/-/tree/master/data)

Comma-separated text-files (csv) containing the data in the directory data/.

- **`l1_data`**: Information on the number of native speakers, mostly from [the Ethnologue](https://www.ethnologue.com/).
- **`l2_data`**: Information on the number of native and non-native speakers, from [Bentz & Winter (2013)](https://doi.org/10.1163/22105832-13030105).
- **`ling_data`**: Data on the number of cases and the dominant word order of transitive clauses.
- **`register`**: Genealogical, geographical and other information on the languages in the database, with three subtypes:
    * IDs: Three codes are provided, the Glottolog code, ISO code, and the WALS code.
    * Genealogical information:
        * The genealogy subset contains information on the genealogical classification of each language. We provide three pieces of information on genealogical classification: 1. language name (as in the [WALS](https://wals.info/languoid/genealogy)), 2. genus, which is an intermediate level in the genealogical classification of the [WALS](https://wals.info/languoid/genealogy), 3. family, which is the highest level in the genealogical classification of the [WALS](https://wals.info/languoid/genealogy), and 4. stock, which is the highest level in the genealogical classification of the [AUTOTYP](https://github.com/autotyp/autotyp-data). See more details about these classifications via the links.
    * Geographical information:
        * The geography subset contains information on the geographical location of each language, namely the longitudes and latitudes. In addition, this subset contains three classifications of languages into areas: 1. a fine-grained classification of languages into 24 areas (as in the [AUTOTYP](https://github.com/autotyp/autotyp-data/blob/master/figures/areas.jpg)), 2. a more coarse-grained classification of languages into ten continents (as in the [AUTOTYP](https://github.com/autotyp/autotyp-data/blob/master/figures/continents.jpg)), and 3. a coarse-grained classification of languages into the six macroareas (as in the [WALS](https://wals.info/languoid)). See more details about these areas following the links.


### [Metadata](https://version.helsinki.fi/gramadapt/linguistic-system-and-sociolinguistic-environment/-/tree/master/metadata)

The data files are associated with metadata files that describe the definitions of each feature and feature value in the data file. The metadata files are provided in YAML format in the directory metadata/.

The following fields are provided for each feature:
- **`Feature`**: the name of the feature
- **`Description`**: the definition of the feature
- **`FeatureType`**: the type of the feature:
    * data = the entries are based on the analysis of linguistic or demographic data
    * register = the entries contain geographical, genealogical and other information about each language
    * quality = the entries contain information about data sources
- **`DataType`**: whether the feature values are of the type categorical, ratio, count or logical
- **`N.entries`**: the number of entries for the feature, excluding blank cells (or 'NA')
- **`N.languages`**: the number of languages in the database with non-blank('NA') feature values
- **`N.missing`**: the number of languages with missing information for the feature
- **`Levels`**: where applicable, the number of distinct levels that a categorical feature may have


### [Scripts](https://version.helsinki.fi/gramadapt/linguistic-system-and-sociolinguistic-environment/-/tree/master/scripts)

This folder contains the R script used for the preprocessing of the data, for the statistical tests, and for drawing the figures.


***

This research has received funding from the European Research Council (ERC) under the European Union’s Horizon 2020 research and innovation programme (grant agreement No 805371), and partly from the Academy of Finland (grant agreement No 296212).
